import axios from 'axios';
import { ElMessageBox, ElMessage } from 'element-plus';
import { getAuthHeaders } from '@/utils/auth';
import { logout } from '@/store/useCurrentUser';

const service = axios.create({
  baseURL: import.meta.env.VITE_BASE_API,
  timeout: 10000,
});
let loaded = 0;
service.interceptors.request.use(
  (config) => {
    config.headers = { ...config.headers, ...getAuthHeaders() };
    return config;
  },
  (error) => Promise.reject(error),
);

service.interceptors.response.use(
  (res) => {
    const { message, status } = res.data;
    if (status) {
      if (status === 200) {
        return res;
      }
      message === '无缓存' || ElMessage.error(message);
    } else {
      return res;
    }
  },
  (e) => {
    const {
      response: {
        data: { message, error },
        status,
      },
    } = e;
    if (status === 401) {
      loaded ||
        ElMessageBox.alert('登录状态已过期，请重新登录', { confirmButtonText: '重新登录', type: 'warning', closeOnClickModal: false, showClose: false }).then(() => {
          // 未登录
          logout();
        });
      loaded = 1;
    } else if (message) {
      ElMessage.error(message);
    }
    return Promise.reject(error);
  },
);

export default service;
